pub type EntityResolver<'input> = dyn Fn(Option<&str>, &str) -> Result<Option<&'input str>, String> + 'input;Expand description
Function to resolve external entities
This function is passed the optional public ID and the mandatory URI of the external entity.
It is expected to yield the content defining the URI, possibly preceeded by a text declaration.
If it yields None, the entity is discarded
and will yield errors if referenced during parsing.
Errors must be stringified so they can be propagated
via Error::EntityResolver.